==> bibledit_1.7.orig.tar.gz: bibledit-1.7/src/htmlbrowser.cpp <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "htmlbrowser.h"
#include <gtk/gtk.h>
#include "gtkwrappers.h"
#include "gwrappers.h"
#include "directories.h"
#include "utilities.h"
#include "unixwrappers.h"
#include "constants.h"
#include "uname.h"
#include <config.h>
#include "windowsoutpost.h"


#define NUMBER_OF_BROWSERS 8


ustring helpcommand (int index)
{
  // Returns a command to be executed to get the helpfile displayed.
  // Variable "index" selects which browser will be used.
  ustring command;
  switch (index)
    {
    case 0:
      {
        command = "htmlview";
        break;
      }
    case 1:
      {
        command = "firefox";
        break;
      }
    case 2:
      {
        command = "mozilla";
        break;
      }
    case 3:
      {
        command = "galeon";
        break;
      }
    case 4:
      {
        command = "konqueror";
        break;
      }
    case 5:
      {
        command = "epiphany";
        break;
      }
    case 6:
      {
        command = "opera";
        break;
      }
    case 7:
      {
        command = "open";
        break;
      }
      // Note: when adding new browsers, ensure that the variabele
      // NUMBER_OF_BROWSERS is updated too.
    }
  return command;
}


void htmlbrowser (const ustring& filename, bool network)
// Get the name of an existing browser, and view the file through it.
{
  // Get the prefix.
  ustring prefix;
  if (network)
    prefix = "http://";
  else
    prefix = "file://";
 
  // Handle if Windows.
  if (uname_get () == untCygwin) {
    ustring url (filename);
    if (!network)
      url = filename_modify_if_cygwin (url);
    url.insert (0, prefix);
    windowsoutpost_open_url (url);
    return; 
  }

  // Handle Unix.
  int browser_index = -1;
  ustring outputfile;
  for (unsigned int i = 0; i < NUMBER_OF_BROWSERS; i++) {
    // At first we used the exit code of "which" to determine whether it had
    // found the program, but this does not work on BSD likes. So now we read
    // the output to see what whether it found the program.
    if (unix_which (helpcommand (i))) {
      browser_index = i;
      break;
    }
  }
  if (browser_index >= 0) {
    ustring command;
    command = helpcommand (browser_index);
    command.append (" '");
    command.append (prefix);
    command.append (filename);
    command.append ("' > /dev/null &");
    system (command.c_str ());
  } else {
    // No suitable browser was found.
    // Inform the user about it, and what to do to solve it.
    ustring message;
    message = "The help cannot be displayed, because there is no suitable browser installed.\n";
    message.append ("Install one of the following supported browsers:\n");
    for (unsigned int i = 0; i < NUMBER_OF_BROWSERS; i++) {
      message.append (helpcommand (i));
      message.append ("\n");
    }
    gtkw_dialog_error (NULL, message);
  }    
}


void http_server_start ()
{
  ustring command;
  command = "bibledit.httpd ";
  command.append (PACKAGE_DATA_DIR);
  command.append (" > /dev/null");
  system (command.c_str());
}


void http_server_stop ()
{
  system ("killall bibledit.httpd");
}

==> bibledit_1.9.orig.tar.gz: bibledit-1.9/src/htmlbrowser.cpp <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "htmlbrowser.h"
#include <gtk/gtk.h>
#include "gtkwrappers.h"
#include "gwrappers.h"
#include "directories.h"
#include "utilities.h"
#include "unixwrappers.h"
#include "constants.h"
#include "uname.h"
#include <config.h>
#include "windowsoutpost.h"


#define NUMBER_OF_BROWSERS 8


ustring helpcommand (int index)
{
  // Returns a command to be executed to get the helpfile displayed.
  // Variable "index" selects which browser will be used.
  ustring command;
  switch (index)
    {
    case 0:
      {
        command = "htmlview";
        break;
      }
    case 1:
      {
        command = "firefox";
        break;
      }
    case 2:
      {
        command = "mozilla";
        break;
      }
    case 3:
      {
        command = "galeon";
        break;
      }
    case 4:
      {
        command = "konqueror";
        break;
      }
    case 5:
      {
        command = "epiphany";
        break;
      }
    case 6:
      {
        command = "opera";
        break;
      }
    case 7:
      {
        command = "open";
        break;
      }
      // Note: when adding new browsers, ensure that
      // NUMBER_OF_BROWSERS is updated too.
    }
  return command;
}


void htmlbrowser (const ustring& filename, bool network)
// Get the name of an existing browser, and view the file through it.
{
  // Get the prefix.
  ustring prefix;
  if (network)
    prefix = "http://";
  else
    prefix = "file://";
 
  // Handle if Windows.
  if (uname_get () == untCygwin) {
    ustring url (filename);
    if (!network)
      url = filename_modify_if_cygwin (url);
    url.insert (0, prefix);
    windowsoutpost_open_url (url);
    return; 
  }

  // Handle Unix.
  int browser_index = -1;
  ustring outputfile;
  for (unsigned int i = 0; i < NUMBER_OF_BROWSERS; i++) {
    // At first we used the exit code of "which" to determine whether it had
    // found the program, but this does not work on BSD likes. So now we read
    // the output to see what whether it found the program.
    if (unix_which (helpcommand (i))) {
      browser_index = i;
      break;
    }
  }
  if (browser_index >= 0) {
    ustring command;
    command = helpcommand (browser_index);
    command.append (" '");
    command.append (prefix);
    command.append (filename);
    command.append ("' > /dev/null &");
    system (command.c_str ());
  } else {
    // No suitable browser was found.
    // Inform the user about it, and what to do to solve it.
    ustring message;
    message = "The help cannot be displayed, because there is no suitable browser installed.\n";
    message.append ("Install one of the following supported browsers:\n");
    for (unsigned int i = 0; i < NUMBER_OF_BROWSERS; i++) {
      message.append (helpcommand (i));
      message.append ("\n");
    }
    gtkw_dialog_error (NULL, message);
  }    
}


void http_server_start ()
{
  ustring command;
  command = "bibledit.httpd ";
  command.append (PACKAGE_DATA_DIR);
  system (command.c_str());
}


void http_server_stop ()
{
  system ("killall bibledit.httpd");
}
